<p align="center">
  <img src="https://raw.githubusercontent.com/SkwalExe/octo-logo/main/assets/logo.png">
</p>

<p align="center">
  <img src="https://img.shields.io/github/license/SkwalExe/octo-logo?style=for-the-badge">
  <img src="https://img.shields.io/github/stars/SkwalExe/octo-logo?style=for-the-badge">
  <img src="https://img.shields.io/github/issues/SkwalExe/octo-logo?color=blueviolet&style=for-the-badge">
  <img src="https://img.shields.io/github/forks/SkwalExe/octo-logo?color=teal&style=for-the-badge">
  <img src="https://img.shields.io/github/issues-pr/SkwalExe/octo-logo?color=tomato&style=for-the-badge">

</p>

<p align="center">💠 Simple logos for complex projects. 💠</p>

# Documentation

[**--> Please head over to our documentation for more information! <--**](https://octologo.skwal.net)

# How to install 📥

You can install octologo easily with pip:

```bash
pip install octologo
```

You can also use [pipx](https://pypa.github.io/pipx/):

```bash
pipx install octologo
```

Now, start the app with the `octologo` command.

# Contributing 🤝

**For contribution instructions, take a look at the `contributing` section of [our documentation](https://octologo.skwal.net/understanding-the-project.html).**
